@@ -350,5 +350,7 @@
 #define __NR_open_by_handle_at  342
 #define __NR_clock_adjtime	343
 #define __NR_syncfs             344
+#define __NR_sendmmsg		345
+#define __NR_setns		346
 
 #endif /* _ASM_X86_UNISTD_32_H */
